@@ -2,6 +2,7 @@ import unittest
 import waveletai
 from waveletai.model import Model, ModelVersion
 from waveletai.experiment import Experiment
+from waveletai.constants import Visibility
 
 
 class ModelTestCase(unittest.TestCase):
@@ -18,7 +19,7 @@ class ModelTestCase(unittest.TestCase):
         waveletai.set_app(app_id)
 
     def test_01_create_model(self):
-        model: Model = waveletai.create_model(name='sdk_test_case')
+        model: Model = waveletai.create_model(name='sdk_test_case', visibility=Visibility.PRIVATE.value)
         globals()["model_id"] = model.id
         # globals()["model_id"] = '16a48da654ce4475ab6084ba2bbdf1be'
         self.assertEqual("sdk_test_case", model.name)
@@ -81,7 +82,7 @@ class ModelTestCase(unittest.TestCase):
         waveletai.set_model(model_id)
         experiment: Experiment = waveletai.create_experiment(name='123')
         globals()["experiment_id"] = experiment.id
-        self.assertEqual('123',experiment.name)
+        self.assertEqual('123', experiment.name)
 
     def test_12_get_experiment(self):
         waveletai.set_app(app_id)
@@ -89,7 +90,6 @@ class ModelTestCase(unittest.TestCase):
         experiment: Experiment = waveletai.get_experiment(experiment_id=experiment_id)
         self.assertEqual(experiment_id, experiment.id)
 
-
     def test_13_list_releases_by_repo(self):
         waveletai.set_app(app_id)
         waveletai.set_model(model_id)
