@@ -29,12 +29,13 @@ from waveletai.model import ModelVersion
 from waveletai.app import App
 from waveletai.exceptions import LoginFailed, NotADirectory, MissingApiTokenException, FileUploadException, \
     InvalidAPIToken
-from waveletai.constants import DataType, ModelRegisterMode, Visibility, FeatureType
+from waveletai.constants import DataType, ModelRegisterMode, Visibility, FeatureType, DataSource
 from waveletai.utils.storage_utils import UploadEntry, scan_upload_entries, SilentProgressIndicator, \
     LoggingProgressIndicator, upload_to_storage
 from waveletai.utils.datastream import FileStream, FileChunkStream, FileChunk
 import zipfile
 from waveletai.experiment import Experiment, MLFlowExperiment, MLFlowRun, MLflowLatestMetric, MLFlowParam, MLFlowTag
+import pandas as pd
 
 _logger = logging.getLogger(__name__)
 
@@ -259,7 +260,7 @@ class HostedBackend(Backend):
 
         entries = scan_upload_entries({UploadEntry(path)})
         upload_to_storage(entries, self._dataset_upload, self._dataset_chunk_upload_loop,
-                          warn_limit=CHUNK_SIZE * 1024 * 1, oid=dataset_id)
+                          warn_limit=WARN_SIZE, oid=dataset_id)
 
     @with_api_exceptions_handler
     # @retrying(stop_max_attempt_number=3)
@@ -370,6 +371,7 @@ class HostedBackend(Backend):
         headers_types = ['application/octet-stream', 'application/zip', 'image/png', 'image/jpeg',
                          'application/vnd.ms-excel', 'text/plain', 'application/json',
                          'application/application/vnd.openxmlformats-officedocument.spreadsheetml.sheet']
+        progress_indicator = None
         with closing(requests.get(url, stream=True)) as response:
             if response.headers.get('Content-Type') not in headers_types:
                 _logger.error(f"当前文件 {filename} 不是可下载的文件流地址，请检查后再试")
@@ -378,12 +380,13 @@ class HostedBackend(Backend):
                 content_size = int(response.headers.get('Content-Length'))  # 内容体总大小
             else:
                 content_size = len(response.content)
-            progress_indicator = SilentProgressIndicator(content_size, filename)
             if content_size >= WARN_SIZE:
                 progress_indicator = LoggingProgressIndicator(content_size, filename)
+            else:
+                progress_indicator = SilentProgressIndicator(content_size, filename)
             with open(destination_loc, 'wb') as f:
                 for data in response.iter_content(chunk_size=CHUNK_SIZE):
-                    progress_indicator.progress(CHUNK_SIZE)
+                    progress_indicator.progress(len(data))
                     f.write(data)
         progress_indicator.complete()
 
@@ -405,7 +408,7 @@ class HostedBackend(Backend):
         """
         :param type
         :param dataset_id:
-        :param path: 当数据集类型为timeseries时 path传参为 None
+        :param path: 当数据集类型为 DataSource.WTHINGS 时 path传参为 None
         :param destination:
         :return:
         """
@@ -418,7 +421,7 @@ class HostedBackend(Backend):
             raise NotADirectory(destination)
 
         try:
-            if type == 'timeseries':
+            if type == DataSource.WTHINGS.value:
                 self._timeseries_download(dataset_id, name, destination)
             else:
                 with Pool(5) as pool:
@@ -488,7 +491,7 @@ class HostedBackend(Backend):
             raise NotADirectory(destination)
 
         try:
-            if type == 'timeseries':
+            if type == DataSource.WTHINGS.value:
                 self._timeseries_download(dataset_id, name, destination)
             else:
                 with Pool(5) as pool:
@@ -589,7 +592,7 @@ class HostedBackend(Backend):
                 progress_indicator = LoggingProgressIndicator(content_size, f'{name}.csv')
             with open(destination_loc, 'wb') as f:
                 for data in res.iter_content(chunk_size=CHUNK_SIZE):
-                    progress_indicator.progress(CHUNK_SIZE)
+                    progress_indicator.progress(len(data))
                     f.write(data)
             progress_indicator.complete()
         except Exception as e:
@@ -1015,8 +1018,7 @@ class HostedBackend(Backend):
         self.model_id = data['model_id']
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], param_json=data['param_json'],
                           host_id=data['host_id'], model_id=data['model_id'], dataset_id=data['dataset_id'],
-                          start_time=data['start_time'], end_time=data['end_time'], state=data['state'],
-                          best_run_id=data['best_run_id'], create_time=data['create_time'],
+                          state=data['state'], best_run_id=data['best_run_id'], create_time=data['create_time'],
                           create_user_id=data['create_user_id'], mlflow_experiments_id=data['mlflow_experiments_id'],
                           ml_experiment=data['ml_experiment'])
 
@@ -1111,8 +1113,7 @@ class HostedBackend(Backend):
         data = res.json()['data']
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], host_id=data['host_id'],
                           param_json=data['param_json'], model_id=data['model_id'], dataset_id=data['dataset_id'],
-                          start_time=data['start_time'], end_time=data['end_time'], state=data['state'],
-                          best_run_id=data['best_run_id'], create_time=data['create_time'],
+                          state=data['state'], best_run_id=data['best_run_id'], create_time=data['create_time'],
                           create_user_id=data['create_user_id'], mlflow_experiments_id=data['mlflow_experiments_id'],
                           ml_experiment=data['ml_experiment'])
 
@@ -1147,11 +1148,10 @@ class HostedBackend(Backend):
         self.set_model(data['model_id'])
         self.set_app(data['model']['app_id'])
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], host_id=data['host_id'],
-                          param_json=data['param_json'],
-                          model_id=data['model_id'], dataset_id=data['dataset_id'], start_time=data['start_time'],
-                          end_time=data['end_time'], state=data['state'], best_run_id=data['best_run_id'],
-                          create_time=data['create_time'], create_user_id=data['create_user_id'],
-                          mlflow_experiments_id=data['mlflow_experiments_id'], ml_experiment=data['ml_experiment'])
+                          param_json=data['param_json'], model_id=data['model_id'], dataset_id=data['dataset_id'],
+                          state=data['state'], best_run_id=data['best_run_id'], create_time=data['create_time'],
+                          create_user_id=data['create_user_id'], mlflow_experiments_id=data['mlflow_experiments_id'],
+                          ml_experiment=data['ml_experiment'])
 
     @with_api_exceptions_handler
     @require_model
@@ -1169,10 +1169,10 @@ class HostedBackend(Backend):
         self.set_app(data['model']['app_id'])
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], host_id=data['host_id'],
                           param_json=data['param_json'],
-                          model_id=data['model_id'], dataset_id=data['dataset_id'], start_time=data['start_time'],
-                          end_time=data['end_time'], state=data['state'], best_run_id=data['best_run_id'],
-                          create_time=data['create_time'], create_user_id=data['create_user_id'],
-                          mlflow_experiments_id=data['mlflow_experiments_id'], ml_experiment=data['ml_experiment'])
+                          model_id=data['model_id'], dataset_id=data['dataset_id'], state=data['state'],
+                          best_run_id=data['best_run_id'], create_time=data['create_time'],
+                          create_user_id=data['create_user_id'], mlflow_experiments_id=data['mlflow_experiments_id'],
+                          ml_experiment=data['ml_experiment'])
 
     @with_api_exceptions_handler
     def create_mlflow_run(self, name, artifact_uri, run_uuid, experiment_id, source_type,
@@ -1425,3 +1425,43 @@ class HostedBackend(Backend):
         dict = res.json()['data']['data']
         return Feature(self, dict['id'], dict['name'], dict['desc'], dict['zone'], dict['type'], dict['json_data'],
                        dict['create_time'], dict['create_user_id'], dict['update_time'], dict['update_user_id'])
+
+    @with_api_exceptions_handler
+    @require_app
+    def download_data(self, dataset_id, path, destination_dir, datasource, fileext, query):
+        """
+        获取外部数据源数据
+        :param dataset_id
+        :param path
+        :param destination_dir
+        :param datasource
+        :param fileext
+        :param query
+        """
+        filename = path
+        if not destination_dir:
+            destination_dir = os.getcwd()
+        if not os.path.exists(destination_dir):
+            os.makedirs(destination_dir)
+        elif not os.path.isdir(destination_dir):
+            raise NotADirectory(destination_dir)
+        client_ip = self._get_ip()
+        try:
+            if DataSource.MAMMUT.value == datasource:
+                res = self._session.post(
+                    url=f'{self.api_address}/{self.app_id}/data/dataset/netease/data/sdk/{dataset_id}',
+                    json={"query": query}, headers={"client-ip": client_ip})
+                if res.json()["message"]:
+                    return res.json()["message"]
+                path = res.json()['data']
+                urls = [(path, destination_dir, path)]
+                self._url_download((path, destination_dir, filename))
+                res = self._session.get(
+                    url=f'{self.api_address}/{self.app_id}/data/dataset/netease/data/sdk/{dataset_id}')
+                if res.json()["message"]:
+                    return res.json()["message"]
+            else:
+                _logger.error("您提供DataSource类型暂不支持")
+                pass
+        except Exception as e:
+            raise e
