@@ -18,6 +18,19 @@ ANONYMOUS_API_TOKEN = 'eyJhcGlfYWRkcmVzcyI6Imh0dHBzOi8vdWkubmVwdHVuZS5haSIsImFwa
                       'kiLCJhcGlfa2V5IjoiYjcwNmJjOGYtNzZmOS00YzJlLTkzOWQtNGJhMDM2ZjkzMmU0In0='
 
 
+@unique
+class DataSource(Enum):
+    WTHINGS = 'timeseries'  # 小波物联
+    MAMMUT = 'mammut'  # 网易猛犸
+
+
+@unique
+class FileExt(Enum):
+    CSV = 'csv'
+    Parquet = 'parquet'
+    # Avro = 'avro'
+
+
 @unique
 class Visibility(Enum):
     # 可见性
